@@ -60,14 +60,8 @@
 #endif /* ALC_ALL_DEVICES_SPECIFIER */
 #endif /* __APPLE__ */
 
-extern FriendsList Friends;
-extern ToxWindow *windows[MAX_WINDOWS_NUM];
-
 struct CallControl CallControl;
 
-extern struct user_settings *user_settings;
-extern struct Winthread Winthread;
-
 void on_call(ToxAV *av, uint32_t friend_number, bool audio_enabled, bool video_enabled,
              void *user_data);
 void on_call_state(ToxAV *av, uint32_t friend_number, uint32_t state, void *user_data);
@@ -204,7 +198,7 @@ static int start_transmission(ToxWindow *self, Call *call)
         return -1;
     }
 
-    DeviceError error = open_input_device(&call->in_idx, read_device_callback, &self->num, false,
+    DeviceError error = open_input_device(&call->in_idx, read_device_callback, &self->num,
                                           CallControl.audio_sample_rate, CallControl.audio_frame_duration, CallControl.audio_channels);
 
     if (error != de_None) {
