@@ -58,12 +58,6 @@
 #endif /* VIDEO */
 #endif /* AUDIO */
 
-extern char *DATA_FILE;
-extern FriendsList Friends;
-
-extern struct Winthread Winthread;
-extern struct user_settings *user_settings;
-
 #ifdef AUDIO
 static void init_infobox(ToxWindow *self);
 static void kill_infobox(ToxWindow *self);
@@ -254,6 +248,7 @@ static void chat_onConnectionChange(ToxWindow *self, Tox *m, uint32_t num, Tox_C
 
     if (prev_status == TOX_CONNECTION_NONE) {
         chat_resume_file_senders(self, m, num);
+        file_send_queue_check(self, m, self->num);
 
         msg = "has come online";
         line_info_add(self, true, nick, NULL, CONNECTION, 0, GREEN, msg);
@@ -798,12 +793,7 @@ void chat_onGameInvite(ToxWindow *self, Tox *m, uint32_t friend_number, const ui
         return;
     }
 
-    Friends.list[friend_number].game_invite.type = type;
-    Friends.list[friend_number].game_invite.id = id;
-    Friends.list[friend_number].game_invite.pending = true;
-
     uint32_t data_length = length - GAME_PACKET_HEADER_SIZE;
-    Friends.list[friend_number].game_invite.data_length = data_length;
 
     if (data_length > 0) {
         free(Friends.list[friend_number].game_invite.data);
@@ -818,6 +808,11 @@ void chat_onGameInvite(ToxWindow *self, Tox *m, uint32_t friend_number, const ui
         Friends.list[friend_number].game_invite.data = buf;
     }
 
+    Friends.list[friend_number].game_invite.type = type;
+    Friends.list[friend_number].game_invite.id = id;
+    Friends.list[friend_number].game_invite.pending = true;
+    Friends.list[friend_number].game_invite.data_length = data_length;
+
     char name[TOX_MAX_NAME_LENGTH];
     get_nick_truncate(m, name, friend_number);
 
@@ -1034,7 +1029,7 @@ static void init_infobox(ToxWindow *self)
 
     ctx->infobox.win = newwin(INFOBOX_HEIGHT, INFOBOX_WIDTH + 1, 1, x2 - INFOBOX_WIDTH);
     ctx->infobox.starttime = get_unix_time();
-    ctx->infobox.vad_lvl = 0.0f;
+    ctx->infobox.vad_lvl = user_settings->VAD_threshold;
     ctx->infobox.active = true;
     strcpy(ctx->infobox.timestr, "00");
 }
@@ -1072,13 +1067,12 @@ static void draw_infobox(ToxWindow *self)
 
     time_t curtime = get_unix_time();
 
-    /* update elapsed time string once per second */
-    if (curtime > infobox->lastupdate) {
+    /* update interface once per second */
+    if (timed_out(infobox->lastupdate, 1)) {
         get_elapsed_time_str(infobox->timestr, sizeof(infobox->timestr), curtime - infobox->starttime);
+        infobox->lastupdate = curtime;
     }
 
-    infobox->lastupdate = curtime;
-
     const char *in_is_muted = infobox->in_is_muted ? "yes" : "no";
     const char *out_is_muted = infobox->out_is_muted ? "yes" : "no";
 
@@ -1271,9 +1265,16 @@ static void chat_onDraw(ToxWindow *self, Tox *m)
     }
 
     ChatContext *ctx = self->chatwin;
+    StatusBar *statusbar = self->stb;
 
     pthread_mutex_lock(&Winthread.lock);
+
     line_info_print(self);
+
+    Tox_Connection connection = statusbar->connection;
+    Tox_User_Status status = statusbar->status;
+    const bool is_typing = Friends.list[self->num].is_typing;
+
     pthread_mutex_unlock(&Winthread.lock);
 
     wclear(ctx->linewin);
@@ -1284,88 +1285,99 @@ static void chat_onDraw(ToxWindow *self, Tox *m)
 
     curs_set(1);
 
-    /* Draw status bar */
-    StatusBar *statusbar = self->stb;
     wmove(statusbar->topline, 0, 0);
 
-    /* Draw name, status and note in statusbar */
-    if (statusbar->connection != TOX_CONNECTION_NONE) {
-        int colour = MAGENTA;
-        Tox_User_Status status = statusbar->status;
+    wattron(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
+    wprintw(statusbar->topline, " [");
+    wattroff(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
 
+    switch (connection) {
+        case TOX_CONNECTION_TCP:
+            wattron(statusbar->topline, A_BOLD | COLOR_PAIR(STATUS_ONLINE));
+            wprintw(statusbar->topline, "TCP");
+            wattroff(statusbar->topline, A_BOLD | COLOR_PAIR(STATUS_ONLINE));
+            break;
+
+        case TOX_CONNECTION_UDP:
+            wattron(statusbar->topline, A_BOLD | COLOR_PAIR(STATUS_ONLINE));
+            wprintw(statusbar->topline, "UDP");
+            wattroff(statusbar->topline, A_BOLD | COLOR_PAIR(STATUS_ONLINE));
+            break;
+
+        default:
+            wattron(statusbar->topline, COLOR_PAIR(BAR_TEXT));
+            wprintw(statusbar->topline, "Offline");
+            wattroff(statusbar->topline, COLOR_PAIR(BAR_TEXT));
+            break;
+    }
+
+    wattron(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
+    wprintw(statusbar->topline, "] ");
+    wattroff(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
+
+    const char *status_text = "ERROR";
+    int colour = BAR_TEXT;
+
+    if (connection != TOX_CONNECTION_NONE) {
         switch (status) {
-            case TOX_USER_STATUS_NONE:
-                colour = STATUS_ONLINE;
-                break;
-
             case TOX_USER_STATUS_AWAY:
                 colour = STATUS_AWAY;
+                status_text = "Away";
                 break;
 
             case TOX_USER_STATUS_BUSY:
                 colour = STATUS_BUSY;
+                status_text = "Busy";
+                break;
+
+            default:
                 break;
         }
+    }
 
+    if (colour != BAR_TEXT) {
         wattron(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
-        wprintw(statusbar->topline, " [");
+        wprintw(statusbar->topline, "[");
         wattroff(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
 
         wattron(statusbar->topline, COLOR_PAIR(colour) | A_BOLD);
-        wprintw(statusbar->topline, "%s", ONLINE_CHAR);
+        wprintw(statusbar->topline, "%s", status_text);
         wattroff(statusbar->topline, COLOR_PAIR(colour) | A_BOLD);
 
         wattron(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
         wprintw(statusbar->topline, "] ");
         wattroff(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
-
-        pthread_mutex_lock(&Winthread.lock);
-        const bool is_typing = Friends.list[self->num].is_typing;
-        pthread_mutex_unlock(&Winthread.lock);
-
-        if (is_typing) {
-            wattron(statusbar->topline, A_BOLD | COLOR_PAIR(BAR_NOTIFY));
-        } else {
-            wattron(statusbar->topline, COLOR_PAIR(BAR_TEXT));
-        }
-
-        wprintw(statusbar->topline, "%s", statusbar->nick);
-
-        if (is_typing) {
-            wattroff(statusbar->topline, A_BOLD | COLOR_PAIR(BAR_NOTIFY));
-        } else {
-            wattroff(statusbar->topline, A_BOLD | COLOR_PAIR(BAR_TEXT));
-        }
-    } else {
-        wattron(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
-        wprintw(statusbar->topline, " [");
-        wattroff(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
-
-        wattron(statusbar->topline, COLOR_PAIR(BAR_TEXT));
-        wprintw(statusbar->topline, "%s", OFFLINE_CHAR);
-        wattroff(statusbar->topline, COLOR_PAIR(BAR_TEXT));
-
-        wattron(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
-        wprintw(statusbar->topline, "] ");
-        wattroff(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
-
-        wattron(statusbar->topline, COLOR_PAIR(BAR_TEXT));
-        wprintw(statusbar->topline, "%s", statusbar->nick);
-        wattroff(statusbar->topline, COLOR_PAIR(BAR_TEXT));
     }
 
+    if (is_typing) {
+        wattron(statusbar->topline, A_BOLD | COLOR_PAIR(BAR_NOTIFY));
+    } else {
+        wattron(statusbar->topline, COLOR_PAIR(BAR_TEXT));
+    }
+
+    wprintw(statusbar->topline, "%s", statusbar->nick);
+
+    if (is_typing) {
+        wattroff(statusbar->topline, A_BOLD | COLOR_PAIR(BAR_NOTIFY));
+    } else {
+        wattroff(statusbar->topline, A_BOLD | COLOR_PAIR(BAR_TEXT));
+    }
+
+
     /* Reset statusbar->statusmsg on window resize */
     if (x2 != self->x) {
         char statusmsg[TOX_MAX_STATUS_MESSAGE_LENGTH] = {'\0'};
 
         pthread_mutex_lock(&Winthread.lock);
+
         tox_friend_get_status_message(m, self->num, (uint8_t *) statusmsg, NULL);
         size_t s_len = tox_friend_get_status_message_size(m, self->num, NULL);
-        pthread_mutex_unlock(&Winthread.lock);
 
         filter_str(statusmsg, s_len);
         snprintf(statusbar->statusmsg, sizeof(statusbar->statusmsg), "%s", statusmsg);
         statusbar->statusmsg_len = strlen(statusbar->statusmsg);
+
+        pthread_mutex_unlock(&Winthread.lock);
     }
 
     self->x = x2;
@@ -1373,19 +1385,27 @@ static void chat_onDraw(ToxWindow *self, Tox *m)
     /* Truncate note if it doesn't fit in statusbar */
     size_t maxlen = x2 - getcurx(statusbar->topline) - (KEY_IDENT_DIGITS * 2) - 6;
 
-    if (statusbar->statusmsg_len > maxlen) {
-        statusbar->statusmsg[maxlen - 3] = '\0';
+    pthread_mutex_lock(&Winthread.lock);
+    size_t statusmsg_len = statusbar->statusmsg_len;
+    pthread_mutex_unlock(&Winthread.lock);
+
+    if (statusmsg_len > maxlen) {
+        pthread_mutex_lock(&Winthread.lock);
+        statusbar->statusmsg[maxlen - 3] = 0;
         strcat(statusbar->statusmsg, "...");
         statusbar->statusmsg_len = maxlen;
+        pthread_mutex_unlock(&Winthread.lock);
     }
 
-    if (statusbar->statusmsg[0]) {
+    if (statusmsg_len > 0) {
         wattron(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
         wprintw(statusbar->topline, " | ");
         wattroff(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
 
         wattron(statusbar->topline, COLOR_PAIR(BAR_TEXT));
+        pthread_mutex_lock(&Winthread.lock);
         wprintw(statusbar->topline, "%s ", statusbar->statusmsg);
+        pthread_mutex_unlock(&Winthread.lock);
     } else {
         wattron(statusbar->topline, COLOR_PAIR(BAR_TEXT));
     }
@@ -1441,7 +1461,11 @@ static void chat_onDraw(ToxWindow *self, Tox *m)
     }
 
     pthread_mutex_lock(&Winthread.lock);
-    refresh_file_transfer_progress(self, self->num);
+
+    if (refresh_file_transfer_progress(self, self->num)) {
+        flag_interface_refresh();
+    }
+
     pthread_mutex_unlock(&Winthread.lock);
 }
 
@@ -1484,6 +1508,7 @@ static void chat_onInit(ToxWindow *self, Tox *m)
 
     /* Init statusbar info */
     StatusBar *statusbar = self->stb;
+
     statusbar->status = get_friend_status(self->num);
     statusbar->connection = get_friend_connection_status(self->num);
 
