@@ -63,8 +63,6 @@
 #include "toxic_strings.h"
 #include "windows.h"
 
-extern char *DATA_FILE;
-
 #define MAX_CONFERENCE_NUM (MAX_WINDOWS_NUM - 2)
 #define CONFERENCE_EVENT_WAIT 30
 
@@ -510,8 +508,7 @@ static void conference_update_name_list(uint32_t conferencenum)
 
         if (peer->active) {
             memcpy(entry->name, peer->name, peer->name_length + 1);
-            bin_pubkey_to_string(peer->pubkey, sizeof(peer->pubkey),
-                                 entry->pubkey_str, sizeof(entry->pubkey_str));
+            tox_pk_bytes_to_str(peer->pubkey, sizeof(peer->pubkey), entry->pubkey_str, sizeof(entry->pubkey_str));
             entry->peernum = i;
             ++count;
         }
@@ -1312,7 +1309,7 @@ bool init_conference_audio_input(Tox *tox, uint32_t conferencenum)
     int channels = user_settings->conference_audio_channels;
 
     bool success = (open_input_device(&chat->audio_in_idx,
-                                      conference_read_device_callback, &chat->audio_input_callback_data, true,
+                                      conference_read_device_callback, &chat->audio_input_callback_data,
                                       CONFAV_SAMPLE_RATE, CONFAV_FRAME_DURATION, channels)
                     == de_None);
 
@@ -1334,7 +1331,7 @@ bool toggle_conference_push_to_talk(uint32_t conferencenum, bool enabled)
     return true;
 }
 
-bool enable_conference_audio(Tox *tox, uint32_t conferencenum)
+bool enable_conference_audio(ToxWindow *self, Tox *tox, uint32_t conferencenum)
 {
     if (!toxav_groupchat_av_enabled(tox, conferencenum)) {
         if (toxav_groupchat_enable_av(tox, conferencenum, audio_conference_callback, NULL) != 0) {
@@ -1342,10 +1339,16 @@ bool enable_conference_audio(Tox *tox, uint32_t conferencenum)
         }
     }
 
-    return init_conference_audio_input(tox, conferencenum);
+    bool success = init_conference_audio_input(tox, conferencenum);
+
+    if (success) {
+        self->is_call = true;
+    }
+
+    return success;
 }
 
-bool disable_conference_audio(Tox *tox, uint32_t conferencenum)
+bool disable_conference_audio(ToxWindow *self, Tox *tox, uint32_t conferencenum)
 {
     ConferenceChat *chat = &conferences[conferencenum];
 
@@ -1358,7 +1361,13 @@ bool disable_conference_audio(Tox *tox, uint32_t conferencenum)
         chat->audio_enabled = false;
     }
 
-    return toxav_groupchat_disable_av(tox, conferencenum) == 0;
+    bool success = toxav_groupchat_disable_av(tox, conferencenum) == 0;
+
+    if (success) {
+        self->is_call = false;
+    }
+
+    return success;
 }
 
 bool conference_mute_self(uint32_t conferencenum)
