@@ -174,6 +174,10 @@ void game_kill(ToxWindow *self)
 
     kill_notifs(self->active_box);
     del_window(self);
+
+    if (get_num_active_windows_type(WINDOW_TYPE_GAME) == 0) {
+        set_window_refresh_rate(NCURSES_DEFAULT_REFRESH_RATE);
+    }
 }
 
 static void game_init_abort(const ToxWindow *parent, ToxWindow *self)
@@ -300,6 +304,8 @@ int game_initialize(const ToxWindow *parent, Tox *m, GameType type, uint32_t id,
 
     set_active_window_index(window_id);
 
+    set_window_refresh_rate(NCURSES_GAME_REFRESH_RATE);
+
     return 0;
 }
 
@@ -511,10 +517,10 @@ static void game_draw_help_bar(const GameData *game, WINDOW *win)
 {
     int max_x;
     int max_y;
-    UNUSED_VAR(max_x);
-
     getmaxyx(win, max_y, max_x);
 
+    UNUSED_VAR(max_x);
+
     wmove(win, max_y - 1, 1);
 
     if (!game->is_multiplayer) {
@@ -540,20 +546,20 @@ static void game_draw_border(const GameData *game, const int max_x, const int ma
     const int x = (max_x - game_max_x) / 2;
     const int y = (max_y - game_max_y) / 2;
 
-    wattron(win, A_BOLD | COLOR_PAIR(GAME_BORDER_COLOUR));
+    wattron(win, COLOR_PAIR(GAME_BORDER_COLOUR));
 
-    mvwaddch(win, y, x, ' ');
-    mvwhline(win, y, x + 1, ' ', game_max_x - 1);
-    mvwvline(win, y + 1, x, ' ', game_max_y - 1);
-    mvwvline(win, y, x - 1, ' ', game_max_y + 1);
-    mvwaddch(win, y, x + game_max_x, ' ');
-    mvwvline(win, y + 1, x + game_max_x, ' ', game_max_y - 1);
-    mvwvline(win, y, x + game_max_x + 1, ' ', game_max_y + 1);
-    mvwaddch(win, y + game_max_y, x, ' ');
-    mvwhline(win, y + game_max_y, x + 1, ' ', game_max_x - 1);
-    mvwaddch(win, y + game_max_y, x + game_max_x, ' ');
+    mvwaddch(win, y, x, ACS_ULCORNER);
+    mvwhline(win, y, x + 1, ACS_HLINE, game_max_x - 1);
+    mvwvline(win, y + 1, x, ACS_VLINE, game_max_y - 1);
+    mvwvline(win, y, x - 1, ACS_VLINE, game_max_y + 1);
+    mvwaddch(win, y, x + game_max_x, ACS_URCORNER);
+    mvwvline(win, y + 1, x + game_max_x, ACS_VLINE, game_max_y - 1);
+    mvwvline(win, y, x + game_max_x + 1, ACS_VLINE, game_max_y + 1);
+    mvwaddch(win, y + game_max_y, x, ACS_LLCORNER);
+    mvwhline(win, y + game_max_y, x + 1, ACS_HLINE, game_max_x - 1);
+    mvwaddch(win, y + game_max_y, x + game_max_x, ACS_LRCORNER);
 
-    wattroff(win, A_BOLD | COLOR_PAIR(GAME_BORDER_COLOUR));
+    wattroff(win, COLOR_PAIR(GAME_BORDER_COLOUR));
 }
 
 static void game_draw_status(const GameData *game, const int max_x, const int max_y)
@@ -561,7 +567,7 @@ static void game_draw_status(const GameData *game, const int max_x, const int ma
     WINDOW *win = game->window;
 
     int x = ((max_x - game->game_max_x) / 2) - 1;
-    int y = ((max_y - game->game_max_y) / 2) - 1;
+    const int y = ((max_y - game->game_max_y) / 2) - 1;
 
     wattron(win, A_BOLD);
 
@@ -931,10 +937,10 @@ int game_y_bottom_bound(const GameData *game)
 {
     int max_x;
     int max_y;
-    UNUSED_VAR(max_x);
-
     getmaxyx(game->window, max_y, max_x);
 
+    UNUSED_VAR(max_x);
+
     return ((max_y + game->game_max_y) / 2) - 1;
 }
 
@@ -942,10 +948,10 @@ int game_y_top_bound(const GameData *game)
 {
     int max_x;
     int max_y;
-    UNUSED_VAR(max_x);
-
     getmaxyx(game->window, max_y, max_x);
 
+    UNUSED_VAR(max_x);
+
     return ((max_y - game->game_max_y) / 2) + 1;
 }
 
@@ -953,10 +959,10 @@ int game_x_right_bound(const GameData *game)
 {
     int max_x;
     int max_y;
-    UNUSED_VAR(max_y);
-
     getmaxyx(game->window, max_y, max_x);
 
+    UNUSED_VAR(max_y);
+
     return ((max_x + game->game_max_x) / 2) - 1;
 }
 
@@ -964,10 +970,10 @@ int game_x_left_bound(const GameData *game)
 {
     int max_x;
     int max_y;
-    UNUSED_VAR(max_y);
-
     getmaxyx(game->window, max_y, max_x);
 
+    UNUSED_VAR(max_y);
+
     return ((max_x - game->game_max_x) / 2) + 1;
 }
 
