@@ -42,11 +42,6 @@
 #include "game_base.h"
 #endif
 
-extern char *DATA_FILE;
-extern ToxWindow *prompt;
-extern FriendsList Friends;
-extern FriendRequests FrndRequests;
-
 /* command functions */
 void cmd_accept(WINDOW *window, ToxWindow *self, Tox *m, int argc, char (*argv)[MAX_STR_SIZE])
 {
@@ -157,21 +152,15 @@ void cmd_add(WINDOW *window, ToxWindow *self, Tox *m, int argc, char (*argv)[MAX
         return;
     }
 
+    char msg[MAX_STR_SIZE] = {0};
+
     const char *id = argv[1];
-    char msg[MAX_STR_SIZE];
+    const size_t arg_length = strlen(id);
+    const int space_idx = char_find(0, id, ' ');
 
-    if (argc > 1) {
-        if (argv[2][0] != '\"') {
-            line_info_add(self, false, NULL, NULL, SYS_MSG, 0, 0, "Message must be enclosed in quotes.");
-            return;
-        }
-
-        /* remove opening and closing quotes */
-        char tmp[MAX_STR_SIZE];
-        snprintf(tmp, sizeof(tmp), "%s", &argv[2][1]);
-        int len = strlen(tmp) - 1;
-        tmp[len] = '\0';
-        snprintf(msg, sizeof(msg), "%s", tmp);
+    // we have to manually parse the message due to this command being a special case
+    if (space_idx > 0 && space_idx < arg_length - 1) {
+        snprintf(msg, sizeof(msg), "%s", &id[space_idx + 1]);
     } else {
         char selfname[TOX_MAX_NAME_LENGTH];
         tox_self_get_name(m, (uint8_t *) selfname);
@@ -182,36 +171,35 @@ void cmd_add(WINDOW *window, ToxWindow *self, Tox *m, int argc, char (*argv)[MAX
     }
 
     char id_bin[TOX_ADDRESS_SIZE] = {0};
-    uint16_t id_len = (uint16_t) strlen(id);
 
-    /* try to add tox ID */
-    if (id_len == 2 * TOX_ADDRESS_SIZE) {
-        size_t i;
-        char xx[3];
-        uint32_t x;
+    const bool is_tox_id = (char_find(0, id, '@') == arg_length) && (arg_length >= TOX_ADDRESS_SIZE * 2);
 
-        for (i = 0; i < TOX_ADDRESS_SIZE; ++i) {
-            xx[0] = id[2 * i];
-            xx[1] = id[2 * i + 1];
-            xx[2] = '\0';
+    if (!is_tox_id) {
+        name_lookup(self, m, id_bin, id, msg);
+    }
 
-            if (sscanf(xx, "%02x", &x) != 1) {
-                line_info_add(self, false, NULL, NULL, SYS_MSG, 0, 0, "Invalid Tox ID.");
-                return;
-            }
+    char xx[3];
+    uint32_t x = 0;
 
-            id_bin[i] = x;
-        }
+    for (size_t i = 0; i < TOX_ADDRESS_SIZE; ++i) {
+        xx[0] = id[2 * i];
+        xx[1] = id[2 * i + 1];
+        xx[2] = 0;
 
-        if (friend_is_blocked(id_bin)) {
-            line_info_add(self, false, NULL, NULL, SYS_MSG, 0, 0, "Friend is in your block list.");
+        if (sscanf(xx, "%02x", &x) != 1) {
+            line_info_add(self, false, NULL, NULL, SYS_MSG, 0, 0, "Invalid Tox ID.");
             return;
         }
 
-        cmd_add_helper(self, m, id_bin, msg);
-    } else {    /* assume id is a username@domain address and do http name server lookup */
-        name_lookup(self, m, id_bin, id, msg);
+        id_bin[i] = x;
     }
+
+    if (friend_is_blocked(id_bin)) {
+        line_info_add(self, false, NULL, NULL, SYS_MSG, 0, 0, "Friend is in your block list.");
+        return;
+    }
+
+    cmd_add_helper(self, m, id_bin, msg);
 }
 
 void cmd_avatar(WINDOW *window, ToxWindow *self, Tox *m, int argc, char (*argv)[MAX_STR_SIZE])
@@ -277,9 +265,9 @@ void cmd_connect(WINDOW *window, ToxWindow *self, Tox *m, int argc, char (*argv)
         return;
     }
 
-    char key_binary[TOX_PUBLIC_KEY_SIZE * 2 + 1];
+    char key_binary[TOX_PUBLIC_KEY_SIZE];
 
-    if (hex_string_to_bin(ascii_key, strlen(ascii_key), key_binary, TOX_PUBLIC_KEY_SIZE) == -1) {
+    if (tox_pk_string_to_bytes(ascii_key, strlen(ascii_key), key_binary, sizeof(key_binary)) == -1) {
         line_info_add(self, false, NULL, NULL, SYS_MSG, 0, 0, "Invalid key.");
         return;
     }
@@ -521,7 +509,7 @@ void cmd_myid(WINDOW *window, ToxWindow *self, Tox *m, int argc, char (*argv)[MA
     char bin_id[TOX_ADDRESS_SIZE];
     tox_self_get_address(m, (uint8_t *) bin_id);
 
-    if (bin_id_to_string(bin_id, sizeof(bin_id), id_string, sizeof(id_string)) == -1) {
+    if (tox_id_bytes_to_str(bin_id, sizeof(bin_id), id_string, sizeof(id_string)) == -1) {
         line_info_add(self, false, NULL, NULL, SYS_MSG, 0, 0, "Failed to print ID.");
         return;
     }
@@ -538,7 +526,7 @@ void cmd_myqr(WINDOW *window, ToxWindow *self, Tox *m, int argc, char (*argv)[MA
     char bin_id[TOX_ADDRESS_SIZE];
     tox_self_get_address(m, (uint8_t *) bin_id);
 
-    if (bin_id_to_string(bin_id, sizeof(bin_id), id_string, sizeof(id_string)) == -1) {
+    if (tox_id_bytes_to_str(bin_id, sizeof(bin_id), id_string, sizeof(id_string)) == -1) {
         line_info_add(self, false, NULL, NULL, SYS_MSG, 0, 0, "Failed to create QR code.");
         return;
     }
@@ -656,12 +644,9 @@ void cmd_note(WINDOW *window, ToxWindow *self, Tox *m, int argc, char (*argv)[MA
 {
     UNUSED_VAR(window);
 
-    if (argc < 1) {
-        line_info_add(self, false, NULL, NULL, SYS_MSG, 0, 0, "Input required.");
-        return;
-    }
+    const char *note = argc >= 1 ? argv[1] : "";
 
-    prompt_update_statusmessage(prompt, m, argv[1]);
+    prompt_update_statusmessage(prompt, m, note);
 }
 
 void cmd_nospam(WINDOW *window, ToxWindow *self, Tox *m, int argc, char (*argv)[MAX_STR_SIZE])
