@@ -148,9 +148,10 @@ static int print_n_chars(WINDOW *win, const char *s, size_t n, int max_y)
 
             int x;
             int y;
-            UNUSED_VAR(x);
             getyx(win, y, x);
 
+            UNUSED_VAR(x);
+
             // make sure cursor will wrap correctly after newline to prevent display bugs
             if (y + 1 >= max_y) {
                 return -1;
@@ -324,10 +325,10 @@ static void line_info_init_line(ToxWindow *self, struct line_info *line)
 {
     int y2;
     int x2;
-    UNUSED_VAR(y2);
-
     getmaxyx(self->window, y2, x2);
 
+    UNUSED_VAR(y2);
+
     const int max_y = y2 - CHATBOX_HEIGHT - WINDOW_BAR_HEIGHT;
     const int max_x = self->show_peerlist ? x2 - 1 - SIDEBAR_WIDTH : x2;
 
@@ -440,6 +441,10 @@ int line_info_add(ToxWindow *self, bool show_timestamp, const char *name1, const
     new_line->noread_flag = false;
     new_line->timestamp = get_unix_time();
 
+    if (type == OUT_MSG || type == OUT_ACTION) {
+        new_line->noread_flag = self->stb->connection == TOX_CONNECTION_NONE;
+    }
+
     line_info_init_line(self, new_line);
 
     hst->queue[hst->queue_size++] = new_line;
@@ -471,8 +476,6 @@ static void line_info_check_queue(ToxWindow *self)
     }
 }
 
-#define NOREAD_FLAG_TIMEOUT 5    /* seconds before a sent message with no read receipt is flagged as unread */
-
 void line_info_print(ToxWindow *self)
 {
     ChatContext *ctx = self->chatwin;
@@ -520,10 +523,10 @@ void line_info_print(ToxWindow *self)
     while (line && numlines++ <= max_y && print_ret == 0) {
         int y;
         int x;
-        UNUSED_VAR(y);
-
         getyx(win, y, x);
 
+        UNUSED_VAR(y);
+
         if (x > 0) { // Prevents us from printing off the screen
             break;
         }
@@ -573,12 +576,6 @@ void line_info_print(ToxWindow *self)
                     wattroff(win, COLOR_PAIR(RED));
                 }
 
-                if (type == OUT_MSG && !line->read_flag) {
-                    if (timed_out(line->timestamp, NOREAD_FLAG_TIMEOUT)) {
-                        line->noread_flag = true;
-                    }
-                }
-
                 waddch(win, '\n');
                 break;
 
@@ -598,12 +595,6 @@ void line_info_print(ToxWindow *self)
                 print_ret = print_wrap(win, line, max_x, max_y);
                 wattroff(win, COLOR_PAIR(YELLOW));
 
-                if (type == OUT_ACTION && !line->read_flag) {
-                    if (timed_out(line->timestamp, NOREAD_FLAG_TIMEOUT)) {
-                        line->noread_flag = true;
-                    }
-                }
-
                 waddch(win, '\n');
                 break;
 
@@ -709,6 +700,8 @@ void line_info_print(ToxWindow *self)
         line = line->next;
     }
 
+    flag_interface_refresh();
+
     /* keep calling until queue is empty */
     if (hst->queue_size > 0) {
         line_info_print(self);
@@ -750,6 +743,8 @@ static bool line_info_screen_fit(ToxWindow *self, struct line_info *line)
 /* puts msg in specified line_info msg buffer */
 void line_info_set(ToxWindow *self, uint32_t id, char *msg)
 {
+    flag_interface_refresh();
+
     struct line_info *line = self->chatwin->hst->line_end;
 
     while (line) {
@@ -765,6 +760,24 @@ void line_info_set(ToxWindow *self, uint32_t id, char *msg)
     }
 }
 
+/* Return the line_info object associated with `id`.
+ * Return NULL if id cannot be found
+ */
+struct line_info *line_info_get(ToxWindow *self, uint32_t id)
+{
+    struct line_info *line = self->chatwin->hst->line_end;
+
+    while (line) {
+        if (line->id == id) {
+            return line;
+        }
+
+        line = line->prev;
+    }
+
+    return NULL;
+}
+
 static void line_info_scroll_up(ToxWindow *self, struct history *hst)
 {
     if (hst->line_start->prev) {
@@ -855,6 +868,10 @@ bool line_info_onKey(ToxWindow *self, wint_t key)
         match = false;
     }
 
+    if (match) {
+        flag_interface_refresh();
+    }
+
     return match;
 }
 
