@@ -125,6 +125,8 @@ void on_self_connection_status(Tox *m, Tox_Connection connection_status, void *u
     UNUSED_VAR(userdata);
     StatusBar *statusbar = prompt->stb;
     statusbar->connection = connection_status;
+
+    flag_interface_refresh();
 }
 
 /* Updates own nick in prompt statusbar */
@@ -338,24 +340,50 @@ static void prompt_onDraw(ToxWindow *self, Tox *m)
     Tox_User_Status status = statusbar->status;
     pthread_mutex_unlock(&Winthread.lock);
 
-    if (connection != TOX_CONNECTION_NONE) {
+    wattron(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
+    wprintw(statusbar->topline, " [");
+    wattroff(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
+
+    switch (connection) {
+        case TOX_CONNECTION_TCP:
+            wattron(statusbar->topline, A_BOLD | COLOR_PAIR(STATUS_ONLINE));
+            wprintw(statusbar->topline, "TCP");
+            wattroff(statusbar->topline, A_BOLD | COLOR_PAIR(STATUS_ONLINE));
+            break;
+
+        case TOX_CONNECTION_UDP:
+            wattron(statusbar->topline, A_BOLD | COLOR_PAIR(STATUS_ONLINE));
+            wprintw(statusbar->topline, "UDP");
+            wattroff(statusbar->topline, A_BOLD | COLOR_PAIR(STATUS_ONLINE));
+            break;
+
+        default:
+            wattron(statusbar->topline, COLOR_PAIR(BAR_TEXT));
+            wprintw(statusbar->topline, "Offline");
+            wattroff(statusbar->topline, COLOR_PAIR(BAR_TEXT));
+            break;
+    }
+
+    wattron(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
+    wprintw(statusbar->topline, "]");
+    wattroff(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
+
+    if (status != TOX_USER_STATUS_NONE) {
         int colour = MAGENTA;
         const char *status_text = "ERROR";
 
         switch (status) {
-            case TOX_USER_STATUS_NONE:
-                status_text = "Online";
-                colour = STATUS_ONLINE;
-                break;
-
             case TOX_USER_STATUS_AWAY:
-                status_text = "Away";
                 colour = STATUS_AWAY;
+                status_text = "Away";
                 break;
 
             case TOX_USER_STATUS_BUSY:
-                status_text = "Busy";
                 colour = STATUS_BUSY;
+                status_text = "Busy";
+                break;
+
+            default:
                 break;
         }
 
@@ -377,18 +405,6 @@ static void prompt_onDraw(ToxWindow *self, Tox *m)
         wprintw(statusbar->topline, " %s", statusbar->nick);
         pthread_mutex_unlock(&Winthread.lock);
     } else {
-        wattron(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
-        wprintw(statusbar->topline, " [");
-        wattroff(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
-
-        wattron(statusbar->topline, COLOR_PAIR(BAR_TEXT));
-        wprintw(statusbar->topline, "Offline");
-        wattroff(statusbar->topline, COLOR_PAIR(BAR_TEXT));
-
-        wattron(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
-        wprintw(statusbar->topline, "]");
-        wattroff(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
-
         wattron(statusbar->topline, COLOR_PAIR(BAR_TEXT));
 
         pthread_mutex_lock(&Winthread.lock);
@@ -408,11 +424,14 @@ static void prompt_onDraw(ToxWindow *self, Tox *m)
         char statusmsg[TOX_MAX_STATUS_MESSAGE_LENGTH];
 
         pthread_mutex_lock(&Winthread.lock);
+
         size_t slen = tox_self_get_status_message_size(m);
         tox_self_get_status_message(m, (uint8_t *) statusmsg);
+
         statusmsg[slen] = '\0';
         snprintf(statusbar->statusmsg, sizeof(statusbar->statusmsg), "%s", statusmsg);
         statusbar->statusmsg_len = strlen(statusbar->statusmsg);
+
         pthread_mutex_unlock(&Winthread.lock);
     }
 
@@ -422,25 +441,29 @@ static void prompt_onDraw(ToxWindow *self, Tox *m)
     uint16_t maxlen = x2 - getcurx(statusbar->topline) - 3;
 
     pthread_mutex_lock(&Winthread.lock);
+    size_t statusmsg_len = statusbar->statusmsg_len;
+    pthread_mutex_unlock(&Winthread.lock);
 
-    if (statusbar->statusmsg_len > maxlen) {
-        statusbar->statusmsg[maxlen - 3] = '\0';
+    if (statusmsg_len > maxlen) {
+        pthread_mutex_lock(&Winthread.lock);
+        statusbar->statusmsg[maxlen - 3] = 0;
         strcat(statusbar->statusmsg, "...");
         statusbar->statusmsg_len = maxlen;
+        pthread_mutex_unlock(&Winthread.lock);
     }
 
-    if (statusbar->statusmsg[0]) {
+    if (statusmsg_len) {
         wattron(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
         wprintw(statusbar->topline, " | ");
         wattroff(statusbar->topline, COLOR_PAIR(BAR_ACCENT));
 
         wattron(statusbar->topline, COLOR_PAIR(BAR_TEXT));
+        pthread_mutex_lock(&Winthread.lock);
         wprintw(statusbar->topline, "%s", statusbar->statusmsg);
+        pthread_mutex_unlock(&Winthread.lock);
         wattroff(statusbar->topline, COLOR_PAIR(BAR_TEXT));
     }
 
-    pthread_mutex_unlock(&Winthread.lock);
-
     int y;
     int x;
     getyx(self->window, y, x);
