@@ -114,25 +114,23 @@ static PyObject *python_api_get_status_message(PyObject *self, PyObject *args)
 
 static PyObject *python_api_get_all_friends(PyObject *self, PyObject *args)
 {
-    size_t       i, ii;
     FriendsList  friends;
-    PyObject    *cur, *ret;
-    char         pubkey_buf[TOX_PUBLIC_KEY_SIZE * 2 + 1];
+    char pubkey_buf[TOX_PUBLIC_KEY_SIZE * 2 + 1];
 
     if (!PyArg_ParseTuple(args, "")) {
         return NULL;
     }
 
     friends = api_get_friendslist();
-    ret     = PyList_New(0);
+    PyObject *ret = PyList_New(0);
 
-    for (i = 0; i < friends.num_friends; i++) {
-        for (ii = 0; ii < TOX_PUBLIC_KEY_SIZE; ii++) {
+    for (size_t i = 0; i < friends.num_friends; i++) {
+        for (size_t ii = 0; ii < TOX_PUBLIC_KEY_SIZE; ii++) {
             snprintf(pubkey_buf + ii * 2, 3, "%02X", friends.list[i].pub_key[ii] & 0xff);
         }
 
         pubkey_buf[TOX_PUBLIC_KEY_SIZE * 2] = '\0';
-        cur = Py_BuildValue("(s,s)", friends.list[i].name, pubkey_buf);
+        PyObject *cur = Py_BuildValue("(s,s)", friends.list[i].name, pubkey_buf);
         PyList_Append(ret, cur);
     }
 
@@ -252,26 +250,26 @@ PyMODINIT_FUNC PyInit_toxic_api(void)
     PyObject *m = PyModule_Create(&toxic_api_module);
     PyObject *global_command_const    = Py_BuildValue("i", GLOBAL_COMMAND_MODE);
     PyObject *chat_command_const      = Py_BuildValue("i", CHAT_COMMAND_MODE);
-    PyObject *groupchat_command_const = Py_BuildValue("i", GROUPCHAT_COMMAND_MODE);
+    PyObject *conference_command_const = Py_BuildValue("i", CONFERENCE_COMMAND_MODE);
     PyObject_SetAttrString(m, "GLOBAL_COMMAND",    global_command_const);
     PyObject_SetAttrString(m, "CHAT_COMMAND",      chat_command_const);
-    PyObject_SetAttrString(m, "GROUPCHAT_COMMAND", groupchat_command_const);
+    PyObject_SetAttrString(m, "CONFERENCE_COMMAND", conference_command_const);
     Py_DECREF(global_command_const);
     Py_DECREF(chat_command_const);
-    Py_DECREF(groupchat_command_const);
+    Py_DECREF(conference_command_const);
     return m;
 }
 
 void terminate_python(void)
 {
-    struct python_registered_func *cur, *old;
-
     if (python_commands.name != NULL) {
         free(python_commands.name);
     }
 
+    struct python_registered_func *cur = NULL;
+
     for (cur = python_commands.next; cur != NULL;) {
-        old = cur;
+        struct python_registered_func *old = cur;
         cur = cur->next;
         free(old->name);
         free(old);
