@@ -32,7 +32,7 @@
 
 #define PASSWORD_EVAL_MAX 512
 
-/* holds user setting values */
+/* Holds user setting values defined in the toxic config file. */
 struct user_settings {
     int autolog;           /* boolean */
     int alerts;            /* boolean */
@@ -96,6 +96,8 @@ struct user_settings {
 #endif
 };
 
+extern struct user_settings *user_settings;
+
 enum settings_values {
     AUTOLOG_OFF = 0,
     AUTOLOG_ON = 1,
