@@ -74,7 +74,7 @@
 #ifdef VIDEO
 #include "video_call.h"
 #endif /* VIDEO */
-ToxAV *av;
+static ToxAV *av;
 #endif /* AUDIO */
 
 #ifdef PYTHON
@@ -98,9 +98,15 @@ ToxWindow *prompt = NULL;
 #define MAX_PASSWORD_LEN 64
 
 struct Winthread Winthread;
-struct cqueue_thread cqueue_thread;
-struct av_thread av_thread;
+static struct cqueue_thread cqueue_thread;
 struct arg_opts arg_opts;
+
+#ifdef AUDIO
+static struct av_thread av_thread;
+#endif
+
+// This struct is not thread safe. It should only ever be written to from the main thread
+// before any other thread that uses it is initialized.
 struct user_settings *user_settings = NULL;
 
 static struct user_password {
@@ -239,6 +245,12 @@ void cb_toxcore_logger(Tox *m, TOX_LOG_LEVEL level, const char *file, uint32_t l
     }
 }
 
+/* Sets ncurses refresh rate. Lower values make it refresh more often. */
+void set_window_refresh_rate(size_t refresh_rate)
+{
+    timeout(refresh_rate);
+}
+
 static void init_term(void)
 {
 #if HAVE_WIDECHAR
@@ -256,7 +268,7 @@ static void init_term(void)
     keypad(stdscr, 1);
     noecho();
     nonl();
-    timeout(30);
+    set_window_refresh_rate(NCURSES_DEFAULT_REFRESH_RATE);
 
     if (has_colors()) {
         short bg_color = COLOR_BLACK;
@@ -383,6 +395,7 @@ static void init_term(void)
         init_pair(BLACK_BG, COLOR_BLACK, bar_bg_color);
         init_pair(PURPLE_BG, COLOR_MAGENTA, bar_bg_color);
         init_pair(BAR_TEXT, bar_fg_color, bar_bg_color);
+        init_pair(BAR_SOLID, bar_bg_color, bar_bg_color);
         init_pair(BAR_ACCENT, bar_accent_color, bar_bg_color);
         init_pair(BAR_NOTIFY, bar_notify_color, bar_bg_color);
         init_pair(STATUS_ONLINE, COLOR_GREEN, bar_bg_color);
@@ -434,9 +447,7 @@ static void cleanup_init_messages(void)
         return;
     }
 
-    int i;
-
-    for (i = 0; i < init_messages.num; ++i) {
+    for (int i = 0; i < init_messages.num; ++i) {
         free(init_messages.msgs[i]);
     }
 
@@ -445,19 +456,16 @@ static void cleanup_init_messages(void)
 
 static void print_init_messages(ToxWindow *toxwin)
 {
-    int i;
-
-    for (i = 0; i < init_messages.num; ++i) {
+    for (int i = 0; i < init_messages.num; ++i) {
         line_info_add(toxwin, NULL, NULL, NULL, SYS_MSG, 0, 0, init_messages.msgs[i]);
     }
 }
 
 static void load_friendlist(Tox *m)
 {
-    size_t i;
     size_t numfriends = tox_self_get_friend_list_size(m);
 
-    for (i = 0; i < numfriends; ++i) {
+    for (size_t i = 0; i < numfriends; ++i) {
         friendlist_onFriendAdded(NULL, m, i, false);
     }
 
@@ -1071,6 +1079,37 @@ static void do_toxic(Tox *m)
     pthread_mutex_unlock(&Winthread.lock);
 }
 
+/* Set interface refresh flag. This should be called whenever the interface changes.
+ *
+ * This function is not thread safe.
+ */
+void flag_interface_refresh(void)
+{
+    Winthread.flag_refresh = 1;
+    Winthread.last_refresh_flag = get_unix_time();
+}
+
+/* How long we wait to idle interface refreshing after last flag set. Should be no less than 2. */
+#define ACTIVE_WIN_REFRESH_TIMEOUT 2
+
+static void poll_interface_refresh_flag(void)
+{
+    pthread_mutex_lock(&Winthread.lock);
+
+    bool flag = Winthread.flag_refresh;
+    time_t t = Winthread.last_refresh_flag;
+
+    pthread_mutex_unlock(&Winthread.lock);
+
+    if (flag == 1 && timed_out(t, ACTIVE_WIN_REFRESH_TIMEOUT)) {
+        pthread_mutex_lock(&Winthread.lock);
+        Winthread.flag_refresh = 0;
+        pthread_mutex_unlock(&Winthread.lock);
+    }
+}
+
+
+/* How often we refresh windows that aren't focused */
 #define INACTIVE_WIN_REFRESH_RATE 10
 
 void *thread_winref(void *data)
@@ -1078,11 +1117,12 @@ void *thread_winref(void *data)
     Tox *m = (Tox *) data;
 
     uint8_t draw_count = 0;
+
     init_signal_catchers();
 
     while (true) {
-        draw_active_window(m);
         draw_count++;
+        draw_active_window(m);
 
         if (Winthread.flag_resize) {
             on_window_resize();
@@ -1096,6 +1136,8 @@ void *thread_winref(void *data)
             pthread_mutex_lock(&Winthread.lock);
             exit_toxic_success(m);
         }
+
+        poll_interface_refresh_flag();
     }
 }
 
@@ -1109,9 +1151,12 @@ void *thread_cqueue(void *data)
         for (size_t i = 2; i < MAX_WINDOWS_NUM; ++i) {
             ToxWindow *toxwin = get_window_ptr(i);
 
-            if ((toxwin != NULL) && (toxwin->type == WINDOW_TYPE_CHAT)
-                    && (get_friend_connection_status(toxwin->num) != TOX_CONNECTION_NONE)) {
-                cqueue_try_send(toxwin, m);
+            if ((toxwin != NULL) && (toxwin->type == WINDOW_TYPE_CHAT)) {
+                cqueue_check_unread(toxwin);
+
+                if (get_friend_connection_status(toxwin->num) != TOX_CONNECTION_NONE) {
+                    cqueue_try_send(toxwin, m);
+                }
             }
         }
 
@@ -1203,21 +1248,23 @@ static void parse_args(int argc, char *argv[])
     };
 
     const char *opts_str = "4bdehLotuxvc:f:l:n:r:p:P:T:";
-    int opt, indexptr;
-    long int port = 0;
+    int opt = 0;
+    int indexptr = 0;
 
     while ((opt = getopt_long(argc, argv, opts_str, long_opts, &indexptr)) != -1) {
         switch (opt) {
-            case '4':
+            case '4': {
                 arg_opts.use_ipv4 = 1;
                 break;
+            }
 
-            case 'b':
+            case 'b': {
                 arg_opts.debug = 1;
                 queue_init_message("stderr enabled");
                 break;
+            }
 
-            case 'c':
+            case 'c': {
                 if (optarg == NULL) {
                     queue_init_message("Invalid argument for option: %d", opt);
                     break;
@@ -1230,17 +1277,20 @@ static void parse_args(int argc, char *argv[])
                 }
 
                 break;
+            }
 
-            case 'd':
+            case 'd': {
                 arg_opts.default_locale = 1;
                 queue_init_message("Using default POSIX locale");
                 break;
+            }
 
-            case 'e':
+            case 'e': {
                 arg_opts.encrypt_data = 1;
                 break;
+            }
 
-            case 'f':
+            case 'f': {
                 if (optarg == NULL) {
                     queue_init_message("Invalid argument for option: %d", opt);
                     break;
@@ -1278,8 +1328,9 @@ static void parse_args(int argc, char *argv[])
                 queue_init_message("Using '%s' data file", DATA_FILE);
 
                 break;
+            }
 
-            case 'l':
+            case 'l': {
                 if (optarg) {
                     arg_opts.logging = true;
 
@@ -1299,13 +1350,15 @@ static void parse_args(int argc, char *argv[])
                 }
 
                 break;
+            }
 
-            case 'L':
+            case 'L': {
                 arg_opts.disable_local_discovery = 1;
                 queue_init_message("Local discovery disabled");
                 break;
+            }
 
-            case 'n':
+            case 'n': {
                 if (optarg == NULL) {
                     queue_init_message("Invalid argument for option: %d", opt);
                     break;
@@ -1313,48 +1366,38 @@ static void parse_args(int argc, char *argv[])
 
                 snprintf(arg_opts.nodes_path, sizeof(arg_opts.nodes_path), "%s", optarg);
                 break;
+            }
 
-            case 'o':
+            case 'o': {
                 arg_opts.no_connect = 1;
                 queue_init_message("DHT disabled");
                 break;
+            }
 
-            case 'p':
-                if (optarg == NULL) {
-                    queue_init_message("Invalid argument for option: %d", opt);
-                    break;
-                }
-
+            case 'p': {
                 arg_opts.proxy_type = TOX_PROXY_TYPE_SOCKS5;
-                snprintf(arg_opts.proxy_address, sizeof(arg_opts.proxy_address), "%s", optarg);
+            }
 
-                if (++optind > argc || argv[optind - 1][0] == '-') {
-                    exit_toxic_err("Proxy error", FATALERR_PROXY);
-                }
+            // Intentional fallthrough
 
-                port = strtol(argv[optind - 1], NULL, 10);
-
-                if (port <= 0 || port > MAX_PORT_RANGE) {
-                    exit_toxic_err("Proxy error", FATALERR_PROXY);
-                }
-
-                arg_opts.proxy_port = port;
-                break;
-
-            case 'P':
+            case 'P': {
                 if (optarg == NULL) {
                     queue_init_message("Invalid argument for option: %d", opt);
+                    arg_opts.proxy_type = TOX_PROXY_TYPE_NONE;
                     break;
                 }
 
-                arg_opts.proxy_type = TOX_PROXY_TYPE_HTTP;
+                if (arg_opts.proxy_type == TOX_PROXY_TYPE_NONE) {
+                    arg_opts.proxy_type = TOX_PROXY_TYPE_HTTP;
+                }
+
                 snprintf(arg_opts.proxy_address, sizeof(arg_opts.proxy_address), "%s", optarg);
 
                 if (++optind > argc || argv[optind - 1][0] == '-') {
                     exit_toxic_err("Proxy error", FATALERR_PROXY);
                 }
 
-                port = strtol(argv[optind - 1], NULL, 10);
+                long int port = strtol(argv[optind - 1], NULL, 10);
 
                 if (port <= 0 || port > MAX_PORT_RANGE) {
                     exit_toxic_err("Proxy error", FATALERR_PROXY);
@@ -1362,8 +1405,9 @@ static void parse_args(int argc, char *argv[])
 
                 arg_opts.proxy_port = port;
                 break;
+            }
 
-            case 'r':
+            case 'r': {
                 if (optarg == NULL) {
                     queue_init_message("Invalid argument for option: %d", opt);
                     break;
@@ -1376,18 +1420,20 @@ static void parse_args(int argc, char *argv[])
                 }
 
                 break;
+            }
 
-            case 't':
+            case 't': {
                 arg_opts.force_tcp = 1;
                 break;
+            }
 
-            case 'T':
+            case 'T': {
                 if (optarg == NULL) {
                     queue_init_message("Invalid argument for option: %d", opt);
                     break;
                 }
 
-                port = strtol(optarg, NULL, 10);
+                long int port = strtol(optarg, NULL, 10);
 
                 if (port <= 0 || port > MAX_PORT_RANGE) {
                     port = MAX_PORT_RANGE;
@@ -1395,21 +1441,25 @@ static void parse_args(int argc, char *argv[])
 
                 arg_opts.tcp_port = port;
                 break;
+            }
 
-            case 'u':
+            case 'u': {
                 arg_opts.unencrypt_data = 1;
                 break;
+            }
 
-            case 'v':
+            case 'v': {
                 print_version();
                 exit(EXIT_SUCCESS);
+            }
 
             case 'h':
 
             // Intentional fallthrough
-            default:
+            default: {
                 print_usage();
                 exit(EXIT_SUCCESS);
+            }
         }
     }
 }
@@ -1598,6 +1648,7 @@ int main(int argc, char **argv)
 
     pthread_mutex_lock(&Winthread.lock);
     print_init_messages(prompt);
+    flag_interface_refresh();
     pthread_mutex_unlock(&Winthread.lock);
 
     cleanup_init_messages();
