@@ -92,21 +92,21 @@ typedef struct VideoDevice {
 
 } VideoDevice;
 
-const char *dvideo_device_names[2];              /* Default device */
-const char *video_devices_names[2][MAX_DEVICES]; /* Container of available devices */
-static int size[2];                        /* Size of above containers */
-VideoDevice *video_devices_running[2][MAX_DEVICES] = {{NULL}};     /* Running devices */
-uint32_t primary_video_device[2];          /* Primary device */
+static const char *dvideo_device_names[2];        /* Default device */
+static char *video_devices_names[2][MAX_DEVICES]; /* Container of available devices */
+static int size[2];                               /* Size of above containers */
+static VideoDevice *video_devices_running[2][MAX_DEVICES] = {{NULL}}; /* Running devices */
+static uint32_t primary_video_device[2];                              /* Primary device */
 
 static ToxAV *av = NULL;
 
 /* q_mutex */
 #define lock pthread_mutex_lock(&video_mutex)
 #define unlock pthread_mutex_unlock(&video_mutex)
-pthread_mutex_t video_mutex;
+static pthread_mutex_t video_mutex;
 
-bool video_thread_running = true,
-     video_thread_paused = true;                /* Thread control */
+static bool video_thread_running = true;
+static bool video_thread_paused = true;                /* Thread control */
 
 void *video_thread_poll(void *);
 
@@ -187,7 +187,7 @@ VideoDeviceError init_video_devices(void)
 
 #if defined(__OSX__) || defined(__APPLE__)
 
-    if (osx_video_init((char **)video_devices_names[vdt_input], &size[vdt_input]) != 0) {
+    if (osx_video_init(&video_devices_names[vdt_input][0], &size[vdt_input]) != 0) {
         return vde_InternalError;
     }
 
@@ -209,12 +209,24 @@ VideoDeviceError init_video_devices(void)
             /* Query V4L for capture capabilities */
             if (-1 != ioctl(fd, VIDIOC_QUERYCAP, &cap)) {
                 video_input_name = (char *)malloc(strlen((const char *)cap.card) + strlen(device_address) + 4);
+
+                if (video_input_name == NULL) {
+                    close(fd);
+                    return vde_InternalError;
+                }
+
                 strcpy(video_input_name, (char *)cap.card);
                 strcat(video_input_name, " (");
                 strcat(video_input_name, (char *)device_address);
                 strcat(video_input_name, ")");
             } else {
                 video_input_name = (char *)malloc(strlen(device_address) + 3);
+
+                if (video_input_name == NULL) {
+                    close(fd);
+                    return vde_InternalError;
+                }
+
                 strcpy(video_input_name, "(");
                 strcat(video_input_name, device_address);
                 strcat(video_input_name, ")");
@@ -229,6 +241,9 @@ VideoDeviceError init_video_devices(void)
 #endif
 
     size[vdt_output] = 1;
+    // TODO(iphydf): String literals are const char *. This may need to be
+    // copied, or if we're not owning any output device names, it should be
+    // const and video_devices_names needs to be split.
     char *video_output_name = "Toxic Video Receiver";
     video_devices_names[vdt_output][0] = video_output_name;
 
@@ -262,7 +277,7 @@ VideoDeviceError terminate_video_devices(void)
     int i;
 
     for (i = 0; i < size[vdt_input]; ++i) {
-        free((void *)video_devices_names[vdt_input][i]);
+        free(video_devices_names[vdt_input][i]);
     }
 
     if (pthread_mutex_destroy(&video_mutex) != 0) {
