@@ -41,16 +41,10 @@
 #include "game_base.h"
 #endif
 
-extern char *DATA_FILE;
-extern struct Winthread Winthread;
-
 ToxWindow *windows[MAX_WINDOWS_NUM];
 static uint8_t active_window_index;
 static int num_active_windows;
 
-extern ToxWindow *prompt;
-extern struct user_settings *user_settings;
-
 /* CALLBACKS START */
 void on_friend_request(Tox *m, const uint8_t *public_key, const uint8_t *data, size_t length, void *userdata)
 {
@@ -77,6 +71,8 @@ void on_friend_connection_status(Tox *m, uint32_t friendnumber, Tox_Connection c
             windows[i]->onConnectionChange(windows[i], m, friendnumber, connection_status);
         }
     }
+
+    flag_interface_refresh();
 }
 
 void on_friend_typing(Tox *m, uint32_t friendnumber, bool is_typing, void *userdata)
@@ -92,6 +88,8 @@ void on_friend_typing(Tox *m, uint32_t friendnumber, bool is_typing, void *userd
             windows[i]->onTypingChange(windows[i], m, friendnumber, is_typing);
         }
     }
+
+    flag_interface_refresh();
 }
 
 void on_friend_message(Tox *m, uint32_t friendnumber, Tox_Message_Type type, const uint8_t *string, size_t length,
@@ -123,6 +121,8 @@ void on_friend_name(Tox *m, uint32_t friendnumber, const uint8_t *string, size_t
         }
     }
 
+    flag_interface_refresh();
+
     store_data(m, DATA_FILE);
 }
 
@@ -140,6 +140,8 @@ void on_friend_status_message(Tox *m, uint32_t friendnumber, const uint8_t *stri
             windows[i]->onStatusMessageChange(windows[i], friendnumber, msg, length);
         }
     }
+
+    flag_interface_refresh();
 }
 
 void on_friend_status(Tox *m, uint32_t friendnumber, Tox_User_Status status, void *userdata)
@@ -151,6 +153,8 @@ void on_friend_status(Tox *m, uint32_t friendnumber, Tox_User_Status status, voi
             windows[i]->onStatusChange(windows[i], m, friendnumber, status);
         }
     }
+
+    flag_interface_refresh();
 }
 
 void on_friend_added(Tox *m, uint32_t friendnumber, bool sort)
@@ -186,7 +190,7 @@ void on_conference_invite(Tox *m, uint32_t friendnumber, Tox_Conference_Type typ
 
     for (uint8_t i = 0; i < MAX_WINDOWS_NUM; ++i) {
         if (windows[i] != NULL && windows[i]->onConferenceInvite != NULL) {
-            windows[i]->onConferenceInvite(windows[i], m, friendnumber, type, (char *) conference_pub_key, length);
+            windows[i]->onConferenceInvite(windows[i], m, friendnumber, type, (const char *) conference_pub_key, length);
         }
     }
 }
@@ -200,6 +204,8 @@ void on_conference_peer_list_changed(Tox *m, uint32_t conferencenumber, void *us
             windows[i]->onConferenceNameListChange(windows[i], m, conferencenumber);
         }
     }
+
+    flag_interface_refresh();
 }
 
 void on_conference_peer_name(Tox *m, uint32_t conferencenumber, uint32_t peernumber, const uint8_t *name,
@@ -238,7 +244,7 @@ void on_file_chunk_request(Tox *m, uint32_t friendnumber, uint32_t filenumber, u
 {
     UNUSED_VAR(userdata);
 
-    struct FileTransfer *ft = get_file_transfer_struct(friendnumber, filenumber);
+    FileTransfer *ft = get_file_transfer_struct(friendnumber, filenumber);
 
     if (!ft) {
         return;
@@ -261,7 +267,7 @@ void on_file_recv_chunk(Tox *m, uint32_t friendnumber, uint32_t filenumber, uint
 {
     UNUSED_VAR(userdata);
 
-    struct FileTransfer *ft = get_file_transfer_struct(friendnumber, filenumber);
+    FileTransfer *ft = get_file_transfer_struct(friendnumber, filenumber);
 
     if (!ft) {
         return;
@@ -269,7 +275,7 @@ void on_file_recv_chunk(Tox *m, uint32_t friendnumber, uint32_t filenumber, uint
 
     for (uint8_t i = 0; i < MAX_WINDOWS_NUM; ++i) {
         if (windows[i] != NULL && windows[i]->onFileRecvChunk != NULL) {
-            windows[i]->onFileRecvChunk(windows[i], m, friendnumber, filenumber, position, (char *) data, length);
+            windows[i]->onFileRecvChunk(windows[i], m, friendnumber, filenumber, position, (const char *) data, length);
         }
     }
 }
@@ -279,7 +285,7 @@ void on_file_recv_control(Tox *m, uint32_t friendnumber, uint32_t filenumber, To
 {
     UNUSED_VAR(userdata);
 
-    struct FileTransfer *ft = get_file_transfer_struct(friendnumber, filenumber);
+    FileTransfer *ft = get_file_transfer_struct(friendnumber, filenumber);
 
     if (!ft) {
         return;
@@ -310,7 +316,7 @@ void on_file_recv(Tox *m, uint32_t friendnumber, uint32_t filenumber, uint32_t k
 
     for (uint8_t i = 0; i < MAX_WINDOWS_NUM; ++i) {
         if (windows[i] != NULL && windows[i]->onFileRecv != NULL) {
-            windows[i]->onFileRecv(windows[i], m, friendnumber, filenumber, file_size, (char *) filename,
+            windows[i]->onFileRecv(windows[i], m, friendnumber, filenumber, file_size, (const char *) filename,
                                    filename_length);
         }
     }
@@ -421,13 +427,15 @@ void set_active_window_index(uint8_t index)
 /* Displays the next window if `ch` is equal to the next window key binding.
  * Otherwise displays the previous window.
  */
-void set_next_window(int ch)
+static void set_next_window(int ch)
 {
+    uint8_t index = 0;
+
     if (ch == user_settings->key_next_tab) {
         for (uint8_t i = active_window_index + 1; i < MAX_WINDOWS_NUM; ++i) {
             if (windows[i] != NULL) {
-                set_active_window_index(i);
-                return;
+                index = i;
+                break;
             }
         }
     } else {
@@ -435,13 +443,13 @@ void set_next_window(int ch)
 
         for (uint8_t i = start; i > 0; --i) {
             if (windows[i] != NULL) {
-                set_active_window_index(i);
-                return;
+                index = i;
+                break;
             }
         }
     }
 
-    set_active_window_index(0);
+    set_active_window_index(index);
 }
 
 /* Deletes window w and cleans up */
@@ -677,10 +685,10 @@ void draw_window_bar(ToxWindow *self)
 
     int cur_x;
     int cur_y;
-    UNUSED_VAR(cur_y);
-
     getyx(win, cur_y, cur_x);
 
+    UNUSED_VAR(cur_y);
+
     wattron(win, COLOR_PAIR(BAR_TEXT));
     mvwhline(win, 0, cur_x, ' ', COLS - cur_x);
     wattroff(win, COLOR_PAIR(BAR_TEXT));
@@ -784,21 +792,43 @@ void draw_active_window(Tox *m)
     pthread_mutex_lock(&Winthread.lock);
     a->alert = WINDOW_ALERT_NONE;
     a->pending_messages = 0;
+    bool flag_refresh = Winthread.flag_refresh;
     pthread_mutex_unlock(&Winthread.lock);
 
-    touchwin(a->window);
-    a->onDraw(a, m);
-    wrefresh(a->window);
+    if (flag_refresh) {
+        touchwin(a->window);
+        a->onDraw(a, m);
+        wrefresh(a->window);
+    }
+
+#ifdef AUDIO
+    else if (a->is_call && timed_out(a->chatwin->infobox.lastupdate, 1)) {
+        touchwin(a->window);
+        a->onDraw(a, m);
+        wrefresh(a->window);
+    }
+
+#endif  // AUDIO
 
 #ifdef GAMES
 
     if (a->type == WINDOW_TYPE_GAME) {
+        if (!flag_refresh) {  // we always want to be continously refreshing game windows
+            touchwin(a->window);
+            a->onDraw(a, m);
+            wrefresh(a->window);
+        }
+
         int ch = getch();
 
         if (ch == ERR) {
             return;
         }
 
+        pthread_mutex_lock(&Winthread.lock);
+        flag_interface_refresh();
+        pthread_mutex_unlock(&Winthread.lock);
+
         if (ch == user_settings->key_next_tab || ch == user_settings->key_prev_tab) {
             set_next_window(ch);
         }
@@ -817,6 +847,10 @@ void draw_active_window(Tox *m)
         return;
     }
 
+    pthread_mutex_lock(&Winthread.lock);
+    flag_interface_refresh();
+    pthread_mutex_unlock(&Winthread.lock);
+
     if (printable == 0 && (ch == user_settings->key_next_tab || ch == user_settings->key_prev_tab)) {
         set_next_window((int) ch);
         return;
@@ -892,10 +926,30 @@ int get_num_active_windows(void)
     return num_active_windows;
 }
 
+/* Returns the number of active windows of given type. */
+size_t get_num_active_windows_type(WINDOW_TYPE type)
+{
+    size_t count = 0;
+
+    for (size_t i = 0; i < MAX_WINDOWS_NUM; ++i) {
+        ToxWindow *w = windows[i];
+
+        if (w == NULL) {
+            continue;
+        }
+
+        if (w->type == type) {
+            ++count;
+        }
+    }
+
+    return count;
+}
+
 /* destroys all chat and conference windows (should only be called on shutdown) */
 void kill_all_windows(Tox *m)
 {
-    for (uint8_t i = 2; i < MAX_WINDOWS_NUM; ++i) {
+    for (size_t i = 2; i < MAX_WINDOWS_NUM; ++i) {
         ToxWindow *w = windows[i];
 
         if (w == NULL) {
