@@ -72,6 +72,7 @@ typedef enum {
     STATUS_BUSY,
     STATUS_AWAY,
     BAR_NOTIFY,
+    BAR_SOLID,
 } C_COLOURS;
 
 /* tab alert types: lower types take priority (this relies on the order of C_COLOURS) */
@@ -97,13 +98,24 @@ typedef enum {
    Uncomment if necessary */
 /* #define URXVT_FIX */
 
+/*
+ * Used to control access to global variables via a mutex, as well as to handle signals.
+ * Any file, variable or data structure that is used by the UI/Window thread and any other thread
+ * must be guarded by `lock`.
+ *
+ * There should only ever be one instance of this struct.
+ */
 struct Winthread {
     pthread_t tid;
     pthread_mutex_t lock;
     volatile sig_atomic_t sig_exit_toxic;
     volatile sig_atomic_t flag_resize;
+    volatile sig_atomic_t flag_refresh;
+    volatile sig_atomic_t last_refresh_flag;
 };
 
+extern struct Winthread Winthread;
+
 struct cqueue_thread {
     pthread_t tid;
 };
@@ -137,6 +149,8 @@ struct arg_opts {
     uint16_t tcp_port;
 };
 
+extern struct arg_opts arg_opts;
+
 typedef struct ToxWindow ToxWindow;
 typedef struct StatusBar StatusBar;
 typedef struct PromptBuf PromptBuf;
@@ -223,6 +237,8 @@ struct ToxWindow {
     WINDOW *window_bar;
 };
 
+extern ToxWindow *windows[MAX_WINDOWS_NUM];
+
 /* statusbar info holder */
 struct StatusBar {
     WINDOW *topline;
@@ -306,6 +322,9 @@ ToxWindow *get_window_ptr(size_t i);
 ToxWindow *get_active_window(void);
 void draw_window_bar(ToxWindow *self);
 
+/* Returns the number of active windows of given type. */
+size_t get_num_active_windows_type(WINDOW_TYPE type);
+
 /* refresh inactive windows to prevent scrolling bugs.
    call at least once per second */
 void refresh_inactive_windows(void);
